@@ -23,30 +23,44 @@
 #' @examples
 #' i14y_search_catalog(query = "noga")
 i14y_search_catalog <- function(
-    query = NULL,
-    language = "de",
-    accessRights = NULL,
-    formats = NULL,
-    publishers = NULL,
-    statuses = NULL,
-    themes = NULL,
-    types = NULL,
-    page = NULL,
-    pageSize = NULL
+  query = NULL,
+  language = "de",
+  accessRights = NULL,
+  formats = NULL,
+  publishers = NULL,
+  statuses = NULL,
+  themes = NULL,
+  types = NULL,
+  page = NULL,
+  pageSize = NULL
 ) {
   check_not_null(language)
   language <- arg_match(language, c("de", "fr", "en", "it"))
   # TODO: validate args
-  check_internet()
+  if (!curl::has_internet()) {
+    message("No internet connection")
+    return(NULL)
+  }
 
   req <- httr2::request("https://input.i14y.admin.ch/api/Catalog/search")
-  req <- httr2::req_user_agent(req, "I14Y R package (https://github.com/lgnbhl/I14Y)")
+  req <- httr2::req_user_agent(
+    req,
+    "I14Y R package (https://github.com/lgnbhl/I14Y)"
+  )
   # req <- httr2::req_url_path_append(req, "/api/Catalog/search")
-  req <- httr2::req_url_query(req,
-      language = language, query = query, accessRights = accessRights,
-      formats = formats, publishers = publishers, statuses = statuses, themes = themes,
-      types = types, page = page, pageSize = pageSize
-    )
+  req <- httr2::req_url_query(
+    req,
+    language = language,
+    query = query,
+    accessRights = accessRights,
+    formats = formats,
+    publishers = publishers,
+    statuses = statuses,
+    themes = themes,
+    types = types,
+    page = page,
+    pageSize = pageSize
+  )
   req <- httr2::req_retry(req, max_tries = 2)
   req <- httr2::req_perform(req)
   resp <- httr2::resp_body_json(req, simplifyVector = TRUE, flatten = TRUE)
